AndroidIconGenerator class
Constructors
- AndroidIconGenerator({required String projectDir, required GenerateConfig config})
Properties
- androidAppSrcMainFolder → String
-
no setter
- appIconPath → String
-
no setter
- config → GenerateConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icName → String
-
final
- icNotificationName → String
-
final
- icRoundName → String
-
final
- platform → String
-
final
- projectDir → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited