MacOSIconGenerator class

Constructors

MacOSIconGenerator({required String projectDir, required GenerateConfig config})

Properties

appIconPath String
no setter
config GenerateConfig
final
hashCode int
The hash code for this object.
no setterinherited
platform String
final
projectDir String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate_icons() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited