GenerateConfig class

Constructors

GenerateConfig({bool? enable, String? appIcon, bool? enablePad, bool? enableMac, bool? enableWatch, String? launchImage, bool? enableRoundIcon, bool? enableCircleIcon, String? firebaseNotificationIcon})
GenerateConfig.fromJson(Map<String, dynamic> json)
factory
GenerateConfig.fromRawJson(String str)
factory

Properties

appIcon String?
getter/setter pair
enable bool?
getter/setter pair
enableCircleIcon bool?
getter/setter pair
enableMac bool?
getter/setter pair
enablePad bool?
getter/setter pair
enableRoundIcon bool?
getter/setter pair
enableWatch bool?
getter/setter pair
firebaseNotificationIcon String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
launchImage String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toRawJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited