ImageUtil class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
convertToRGBA(
Image image) → Image -
createCircleIcon(
Image img) → Image -
createCornerRadiusIcon(
{required Image img, required int radius}) → Image -
hasAlphaChannel(
String imagePath) → bool -
is1024(
String filePath) → bool -
remove_alpha_if_needed(
String imagePath) → Future< void>